@@ -490,16 +490,22 @@ public:
 
     /**
      * Somewhat like a comparison operator, but more explicit,
-     * and it can detect that two kfileitems are equal even when they do
-     * not share the same internal pointer - e.g. when KDirLister compares
-     * fileitems after listing a directory again, to detect changes.
+     * and it can detect that two fileitems differ if any property of the file item
+     * has changed (file size, modification date, etc.). Two items are equal if
+     * all properties are equal. In contrast, operator== only compares URLs.
      * @param item the item to compare
      * @return true if all values are equal
      */
     bool cmp( const KFileItem & item ) const;
 
+    /**
+     * Returns true if both items share the same URL.
+     */
     bool operator==(const KFileItem& other) const;
 
+    /**
+     * Returns true if both items do not share the same URL.
+     */
     bool operator!=(const KFileItem& other) const;
 
 
@@ -646,6 +652,8 @@ private:
 private:
     KIO_EXPORT friend QDataStream & operator<< ( QDataStream & s, const KFileItem & a );
     KIO_EXPORT friend QDataStream & operator>> ( QDataStream & s, KFileItem & a );
+
+    friend class KFileItemTest;
 };
 
 Q_DECLARE_METATYPE(KFileItem)
